Class: Ratch::Script

Inherits:
DSL show all
Defined in:
lib/ratch/script.rb

Overview

Ratch Script

The Ratch Script class is used to run stand-alone ratch scripts. Yep, this is actaully a class named exactly for what it is. How rare.

Instance Attribute Summary

Attributes inherited from DSL

#cli, #fio, #io

Method Summary

Methods inherited from DSL

#apply_naming_policy, #ask, #configuration, #configuration!, #current_platform, #debug?, #dir!, #dir?, #dryrun?, #email, #exists!, #exists?, #file!, #file?, #file_read, #file_write, #force?, #home, #initialize, #method_missing, #naming_policy, #password, #pretend?, #quiet?, #root, #shell, #status, #trace?, #verbose?, #work

Constructor Details

This class inherits a constructor from Ratch::DSL

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Ratch::DSL